@@ -1210,6 +1210,7 @@ select(STDOUT);
 
 	return map $object{$_}->{directory} . "xs/$_.xs", sort grep (defined $object{$_}->{cast}, keys %object);
 
+
 #open(OUT,">Objects.xpl") or die "Unable to write to Objects.xpl: $!";
 #
 #print "\n\n# Do not edit this file, as it is automatically generated by gendefs.pl\n\n";
@@ -1221,6 +1222,36 @@ select(STDOUT);
 #print "\"\n;\n";
 
 
+# Write out the data structures documentation
+
+sub gen_doc {
+	print STDERR "Creating reference documentation\n";
+	open (DOC, ">build/perl-gtk-ds.pod") || die "Cannot open doc file: $!";
+	#print DOC "\n=head1 NAME\n\nPerl/Gtk data structures reference\n\n";
+
+	print DOC "=head1 Enumerations\n\n";
+	foreach (sort keys %enum) {
+		print DOC "=head2 $enum{$_}->{perlname}\n\n";
+		print DOC "=over 4\n\n";
+		foreach $v (@{$enum{$_}->{'values'}}) {
+			print DOC "=item * $v->{simple}\n\n";
+		}
+		print DOC "=back\n\n";
+	}
+
+	print DOC "=head1 Flags\n\n";
+	foreach (sort keys %flags) {
+		print DOC "=head2 $flags{$_}->{perlname}\n\n";
+		print DOC "=over 4\n\n";
+		foreach $v (@{$flags{$_}->{'values'}}) {
+			print DOC "=item * $v->{simple}\n\n";
+		}
+		print DOC "=back\n\n";
+	}
+
+	close(DOC);
+}
+
 }
 
 1;
